==> jc-1.4.0.tar.gz: java/util/LocaleData.h <==
// class java.util.LocaleData

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b603025f769c5c9d java_util_LocaleData

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_LocaleData_H_
#define _JC_java_util_LocaleData_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_util_LocaleData$sub_refs	_jc_java_util_LocaleData$sub_refs;
typedef struct _jc_java_util_LocaleData$sub_nonrefs	_jc_java_util_LocaleData$sub_nonrefs;
typedef struct _jc_java_util_LocaleData$refs	_jc_java_util_LocaleData$refs;
typedef struct _jc_java_util_LocaleData$nonrefs	_jc_java_util_LocaleData$nonrefs;
typedef struct _jc_java_util_LocaleData$object	_jc_java_util_LocaleData$object;

typedef struct _jc_java_util_LocaleData$fields_struct	_jc_java_util_LocaleData$fields_struct;
typedef const struct _jc_java_util_LocaleData$vmethods	_jc_java_util_LocaleData$vmethods;
typedef const struct _jc_java_util_LocaleData$vtable	_jc_java_util_LocaleData$vtable;
typedef const struct _jc_java_util_LocaleData$vtype	_jc_java_util_LocaleData$vtype;

// Class fields structure
struct _jc_java_util_LocaleData$fields_struct {
	_jc_object_array	*localeNames;
};
extern _jc_java_util_LocaleData$fields_struct _jc_java_util_LocaleData$class_fields;

// Constructors
extern void _jc_java_util_LocaleData$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_LocaleData$object *);

// Static methods
extern void _jc_java_util_LocaleData$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_util_LocaleData$vmethods {
};

// Vtable
struct _jc_java_util_LocaleData$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_LocaleData$vmethods	java_util_LocaleData;
};

// Vtype
struct _jc_java_util_LocaleData$vtype {
	_jc_type			type;
	_jc_java_util_LocaleData$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_LocaleData$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_LocaleData$refs {
    _jc_java_util_LocaleData$sub_refs	java_util_LocaleData;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_LocaleData$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_LocaleData$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_LocaleData$sub_nonrefs	java_util_LocaleData;
};

// Object instance structure
struct _jc_java_util_LocaleData$object {
	_jc_java_util_LocaleData$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_LocaleData$vtype	*vtype;
	_jc_java_util_LocaleData$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_LocaleData$vtype _jc_java_util_LocaleData$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_LocaleData, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_LocaleData$class_object;

#endif	/* _JC_java_util_LocaleData_H_ */

==> jc-1.4.5.tar.gz: java/util/LocaleData.h <==
// class java.util.LocaleData

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b603025f769c5c9d java_util_LocaleData

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_LocaleData_H_
#define _JC_java_util_LocaleData_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_util_LocaleData$sub_refs	_jc_java_util_LocaleData$sub_refs;
typedef struct _jc_java_util_LocaleData$sub_nonrefs	_jc_java_util_LocaleData$sub_nonrefs;
typedef struct _jc_java_util_LocaleData$refs	_jc_java_util_LocaleData$refs;
typedef struct _jc_java_util_LocaleData$nonrefs	_jc_java_util_LocaleData$nonrefs;
typedef struct _jc_java_util_LocaleData$object	_jc_java_util_LocaleData$object;

typedef struct _jc_java_util_LocaleData$fields_struct	_jc_java_util_LocaleData$fields_struct;
typedef const struct _jc_java_util_LocaleData$vmethods	_jc_java_util_LocaleData$vmethods;
typedef const struct _jc_java_util_LocaleData$vtable	_jc_java_util_LocaleData$vtable;
typedef const struct _jc_java_util_LocaleData$vtype	_jc_java_util_LocaleData$vtype;

// Class fields structure
struct _jc_java_util_LocaleData$fields_struct {
	_jc_object_array	*localeNames;
};
extern _jc_java_util_LocaleData$fields_struct _jc_java_util_LocaleData$class_fields;

// Constructors
extern void _jc_java_util_LocaleData$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_LocaleData$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_util_LocaleData$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_LocaleData$vmethods {
};

// Vtable
struct _jc_java_util_LocaleData$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_LocaleData$vmethods	java_util_LocaleData;
};

// Vtype
struct _jc_java_util_LocaleData$vtype {
	_jc_type			type;
	_jc_java_util_LocaleData$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_LocaleData$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_LocaleData$refs {
    _jc_java_util_LocaleData$sub_refs	java_util_LocaleData;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_LocaleData$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_LocaleData$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_LocaleData$sub_nonrefs	java_util_LocaleData;
};

// Object instance structure
struct _jc_java_util_LocaleData$object {
	_jc_java_util_LocaleData$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_LocaleData$vtype	*vtype;
	_jc_java_util_LocaleData$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_LocaleData$vtype _jc_java_util_LocaleData$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_LocaleData, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_LocaleData$class_object;

#endif	/* _JC_java_util_LocaleData_H_ */
